@@ -35,6 +35,11 @@ func RequestPropertyOneOfUpdatedCheck(diffReport *diff.Diff, operationsSources *
 					continue
 				}
 
+				// Check for suppression by ListOfTypes checker
+				if shouldSuppressOneOfSchemaChangedForListOfTypes(mediaTypeDiff.SchemaDiff) {
+					continue
+				}
+
 				if mediaTypeDiff.SchemaDiff.OneOfDiff != nil && len(mediaTypeDiff.SchemaDiff.OneOfDiff.Added) > 0 {
 					result = append(result, NewApiChange(
 						RequestBodyOneOfAddedId,
@@ -68,6 +73,11 @@ func RequestPropertyOneOfUpdatedCheck(diffReport *diff.Diff, operationsSources *
 							return
 						}
 
+						// Check for suppression by ListOfTypes checker
+						if shouldSuppressPropertyOneOfSchemaChangedForListOfTypes(propertyDiff) {
+							return
+						}
+
 						propName := propertyFullName(propertyPath, propertyName)
 
 						if len(propertyDiff.OneOfDiff.Added) > 0 {
