@@ -32,6 +32,11 @@ func ResponsePropertyTypeChangedCheck(diffReport *diff.Diff, operationsSources *
 				modifiedMediaTypes := responseDiff.ContentDiff.MediaTypeModified
 				for mediaType, mediaTypeDiff := range modifiedMediaTypes {
 					if mediaTypeDiff.SchemaDiff != nil {
+						// Check for suppression by ListOfTypes checker
+						if shouldSuppressTypeChangedForListOfTypes(mediaTypeDiff.SchemaDiff) {
+							continue
+						}
+
 						schemaDiff := mediaTypeDiff.SchemaDiff
 						typeDiff := schemaDiff.TypeDiff
 						formatDiff := schemaDiff.FormatDiff
@@ -57,6 +62,11 @@ func ResponsePropertyTypeChangedCheck(diffReport *diff.Diff, operationsSources *
 								return
 							}
 
+							// Check for suppression by ListOfTypes checker
+							if shouldSuppressPropertyTypeChangedForListOfTypes(propertyDiff) {
+								return
+							}
+
 							schemaDiff := propertyDiff
 							typeDiff := schemaDiff.TypeDiff
 							formatDiff := schemaDiff.FormatDiff
