@@ -8,12 +8,12 @@ func (diff *ExtensionsDiff) Empty() bool {
 	return (*InterfaceMapDiff)(diff).Empty()
 }
 
-func getExtensionsDiff(config *Config, state *state, extensions1, extensions2 map[string]interface{}) (*ExtensionsDiff, error) {
+func getExtensionsDiff(config *Config, extensions1, extensions2 map[string]interface{}) (*ExtensionsDiff, error) {
 	if config.IsExcludeExtensions() {
 		return nil, nil
 	}
 
-	diff, err := getExtensionsDiffInternal(state, extensions1, extensions2)
+	diff, err := getExtensionsDiffInternal(extensions1, extensions2)
 	if err != nil {
 		return nil, err
 	}
@@ -25,6 +25,6 @@ func getExtensionsDiff(config *Config, state *state, extensions1, extensions2 ma
 	return (*ExtensionsDiff)(diff), nil
 }
 
-func getExtensionsDiffInternal(state *state, extensions1, extensions2 map[string]interface{}) (*InterfaceMapDiff, error) {
+func getExtensionsDiffInternal(extensions1, extensions2 map[string]interface{}) (*InterfaceMapDiff, error) {
 	return getInterfaceMapDiff(extensions1, extensions2)
 }
